;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "vim-tab-bar" "20250914.124"
  "Vim-like tab bar."
  '((emacs "28.1"))
  :url "https://github.com/jamescherti/vim-tab-bar.el"
  :commit "ec339632e0fa52045fc4bdc7fcfaee60d6e8eff1"
  :revdesc "ec339632e0fa"
  :keywords '("frames"))
